@@ -210,6 +210,9 @@ Cladewise.matrix <- function (tree, nTip = min(tree[, 1]) - 1L, edge) {
   }
 }
 
+#' @rdname Reorder
+#' @export
+Cladewise.NULL <- function (tree, nTip = min(tree[, 1]) - 1L, edge) NULL
 
 #' @describeIn Reorder Reorder tree in Postorder using ape's `postorder`
 #' function, which is robust to unconventional node numbering.
@@ -240,6 +243,10 @@ ApePostorder.list <- function (tree, nTip, edge) {
   lapply(tree, ApePostorder)
 }
 
+#' @rdname Reorder
+#' @export
+ApePostorder.NULL <- function (tree, nTip, edge) NULL
+
 #' @rdname Reorder
 #' @export
 ApePostorder.multiPhylo <- function (tree, nTip, edge) {
@@ -272,6 +279,10 @@ Postorder.phylo <- function (tree, force = FALSE, renumber = FALSE) {
   tree
 }
 
+#' @rdname Reorder
+#' @export
+Postorder.NULL <- function (tree, force = FALSE, renumber = FALSE) NULL
+
 #' @rdname Reorder
 #' @export
 Postorder.list <- function (tree, force = FALSE, renumber = FALSE) {
@@ -352,6 +363,11 @@ Pruningwise.multiPhylo <- function (tree, nTip, edge) {
   tree
 }
 
+#' @rdname Reorder
+#' @export
+Pruningwise.NULL <- function (tree, nTip, edge) NULL
+
+
 #' @describeIn Reorder Reorder tree in Preorder (special case of cladewise).
 #' @export
 Preorder <- function (tree) UseMethod('Preorder')
@@ -394,6 +410,10 @@ Preorder.list <- function (tree) {
   lapply(tree, Preorder)
 }
 
+#' @rdname Reorder
+#' @export
+Preorder.NULL <- function (tree) NULL
+
 
 #' Renumber a tree's tips
 #'
@@ -453,3 +473,7 @@ RenumberTips.multiPhylo <- function (tree, tipOrder) {
 RenumberTips.list <- function (tree, tipOrder) {
   lapply(tree, RenumberTips, tipOrder)
 }
+
+#' @rdname RenumberTips
+#' @export
+RenumberTips.NULL <- function (tree, tipOrder) NULL
